==> org.eclipse.papyrus.sysml14.validation.source_0.11.0.201706270122.jar: org/eclipse/papyrus/sysml14/validation/rules/blocks/DistributedPropertyTypedByModelConstraint.java <==
/*****************************************************************************
 * Copyright (c) 2016 CEA LIST and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Benoit Maggi (CEA LIST) benoit.maggi@cea.fr - Initial API and implementation
 *   
 *****************************************************************************/
package org.eclipse.papyrus.sysml14.validation.rules.blocks;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.emf.validation.AbstractModelConstraint;
import org.eclipse.emf.validation.IValidationContext;
import org.eclipse.papyrus.sysml14.blocks.Block;
import org.eclipse.papyrus.sysml14.blocks.DistributedProperty;
import org.eclipse.papyrus.sysml14.blocks.ValueType;
import org.eclipse.uml2.uml.Property;
import org.eclipse.uml2.uml.Type;
import org.eclipse.uml2.uml.util.UMLUtil;

/**
 * 8.3.2.8  DistributedProperty [1] The DistributedProperty stereotype may be applied only to properties of classifiers stereotyped by Block or ValueType.
 *
 */
public class DistributedPropertyTypedByModelConstraint extends AbstractModelConstraint {

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.emf.validation.AbstractModelConstraint#validate(org.eclipse.
	 * emf.validation.IValidationContext)
	 */
	@Override
	public IStatus validate(IValidationContext context) {
		DistributedProperty distributedProperty = (DistributedProperty) context.getTarget();
		Property property = distributedProperty.getBase_Property();
		if (property != null) {
			Type type = property.getType();
			if (type != null) {
				if (UMLUtil.getStereotypeApplication(type, ValueType.class) == null
						&& UMLUtil.getStereotypeApplication(type, Block.class) == null) {
					return context.createFailureStatus(context.getTarget());
				}		
			}
		}
		return context.createSuccessStatus();
	}

}

==> org.eclipse.papyrus.sysml14.validation.source_1.2.0.jar: org/eclipse/papyrus/sysml14/validation/rules/blocks/DistributedPropertyTypedByModelConstraint.java <==
/*****************************************************************************
 * Copyright (c) 2016 CEA LIST and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Benoit Maggi (CEA LIST) benoit.maggi@cea.fr - Initial API and implementation
 *   
 *****************************************************************************/
package org.eclipse.papyrus.sysml14.validation.rules.blocks;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.emf.validation.AbstractModelConstraint;
import org.eclipse.emf.validation.IValidationContext;
import org.eclipse.papyrus.sysml14.blocks.Block;
import org.eclipse.papyrus.sysml14.blocks.DistributedProperty;
import org.eclipse.papyrus.sysml14.blocks.ValueType;
import org.eclipse.uml2.uml.Element;
import org.eclipse.uml2.uml.Property;
import org.eclipse.uml2.uml.util.UMLUtil;

/**
 * 8.3.2.8  DistributedProperty [1] The DistributedProperty stereotype may be applied only to properties of classifiers stereotyped by Block or ValueType.
 *
 */
public class DistributedPropertyTypedByModelConstraint extends AbstractModelConstraint {

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.emf.validation.AbstractModelConstraint#validate(org.eclipse.
	 * emf.validation.IValidationContext)
	 */
	@Override
	public IStatus validate(IValidationContext context) {
		DistributedProperty distributedProperty = (DistributedProperty) context.getTarget();
		Property property = distributedProperty.getBase_Property();
		if (property != null) {
			Element owner = property.getOwner();
			if (owner != null) {
				if (UMLUtil.getStereotypeApplication(owner, ValueType.class) == null
						&& UMLUtil.getStereotypeApplication(owner, Block.class) == null) {
					return context.createFailureStatus(context.getTarget());
				}		
			}
		}
		return context.createSuccessStatus();
	}

}
